// O(N^2*K + N*K*log(K) + N*log(N)) solution. But in practice the N^2 part is
// very pessimistic (TODO: think about hard test cases or improve the
// bound).

#include <algorithm>
#include <iostream>
#include <vector>

using namespace std;

struct Candidate {
  int sum;
  vector<int> weights;
  bool operator<(const Candidate &c) const {
    // Ignore the weights.
    return sum < c.sum;
  }
  bool operator==(const Candidate &c) const { return sum == c.sum; }
};

int main() {
  int N, K;
  cin >> N >> K;
  vector<int> weights(N);
  for (int i = 0; i < N; ++i) {
    cin >> weights[i];
  }
  std::sort(weights.begin(), weights.end());
  vector<Candidate> possible = {{0, vector<int>()}};

  int skip_larger_than = 1<<30;
  int sorted_end_index = possible.size();
  for (int w : weights) {
    int sz_before = possible.size();
    for (int i = 0; i < sz_before; ++i) {
      int new_sum = possible[i].sum + w;
      if (new_sum > skip_larger_than) {
	continue;
      }
      if (binary_search(possible.begin(), possible.begin() + sorted_end_index, Candidate{new_sum, {}})) {
	continue;
      }
      vector<int> new_weights(possible[i].weights);
      new_weights.push_back(w);
      possible.push_back({new_sum, new_weights});
    }
    std::sort(possible.begin(), possible.end());
    possible.erase(std::unique(possible.begin(), possible.end()),
                   possible.end());
    if (possible.size() > K) {
      possible.erase(possible.begin() + K, possible.end());
    }
    if (possible.size() >= K) {
      skip_larger_than = possible.back().sum;
    }
    sorted_end_index = possible.size();
  }
  for (const Candidate &candidate : possible) {
    cout << candidate.sum << ": ";
    for (int w : candidate.weights) {
      cout << w << " ";
    }
    cout << endl;
  }
}
