// O(N*K*logK) solution using std::list.

#include <algorithm>
#include <iostream>
#include <list>
#include <vector>

using namespace std;

struct Candidate {
  int sum;
  int last_weight;
  std::list<Candidate>::const_iterator previous_c;

  bool operator<(const Candidate &c) {
    // Ignore the weights.
    return sum < c.sum;
  }
  bool operator==(const Candidate &c) { return sum == c.sum; }
};

int main() {
  int N, K;
  cin >> N >> K;
  vector<int> weights(N);
  for (int i = 0; i < N; ++i) {
    cin >> weights[i];
  }

  list<Candidate> possible;
  possible.push_back({0, -1, possible.end()});

  for (int w : weights) {
    list<Candidate> new_possible;
    for (auto it = possible.begin(); it != possible.end(); ++it) {
      new_possible.push_back({it->sum + w, w, it});
    }
    possible.splice(possible.end(), new_possible);
    possible.sort();
    possible.unique();
    while (possible.size() > K) {
      // It's guaranteed that we don't orphan an iterator this way.
      possible.pop_back();
    }
  }
  for (list<Candidate>::const_iterator it = possible.begin();
       it != possible.end(); ++it) {
    auto it2 = it;
    cout << it->sum << ": ";
    while (it2->last_weight >= 0) {
      cout << it2->last_weight << " ";
      it2 = it2->previous_c;
    }
    cout << endl;
  }
}
